{{!
    This file is part of Moodle - http://moodle.org/
    Moodle is free software: you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
    the Free Software Foundation, either version 3 of the License, or
    (at your option) any later version.
    Moodle is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    GNU General Public License for more details.
    You should have received a copy of the GNU General Public License
    along with Moodle.  If not, see <http://www.gnu.org/licenses/>.
}}
{{!
    @template gradereport_user/action_bar

    Actions bar for the grade user report.

    Context variables required for this template:
    * generalnavselector - The data object containing the required properties to render the general navigation selector.
    * groupselector - (optional) HTML that outputs the group selector
    * userselector - (optional) The data object containing the required properties to render the user selector
    * viewasselector - (optional) HTML that outputs the 'view report as' selector

    Example context (json):
    {
        "generalnavselector": {
            "name": "Gradebook tertiary navigation selector",
            "value": "opt2",
            "baseid": "select-menu56789",
            "selectedoption": "Gradebook setup",
            "options": [
                {
                    "selected": false,
                     "isgroup": {
                         "name": "View",
                         "id": "select-menu-group1",
                         "options": [
                             {
                                 "name": "Grader report",
                                 "value": "opt1",
                                 "id": "select-menu-option1",
                                 "selected": false
                             }
                         ]
                     }
                },
                {
                    "selected": false,
                    "isgroup": {
                        "name": "Setup",
                        "id": "select-menu-group2",
                        "options": [
                            {
                                "name": "Gradebook setup",
                                "value": "opt2",
                                "id": "select-menu-option2",
                                "selected": true
                            }
                        ]
                    }
                }
            ]
        },
        "groupselector": "<div class='group-selector'></div>",
        "userselector": {
            "content": "<div class='user-selector'></div>",
            "courseid": 25
        },
        "viewasselector": "<div class='view-user-selector'></div>"
    }
}}
<div class="container-fluid tertiary-navigation full-width-bottom-border">
    <div class="d-flex flex-wrap">
        {{#generalnavselector}}
            <div class="navitem">
                {{>core/tertiary_navigation_selector}}
            </div>
            <div class="navitem-divider"></div>
        {{/generalnavselector}}
        {{#groupselector}}
            <div class="navitem">
                {{>core/comboboxsearch}}
            </div>
            <div class="navitem-divider"></div>
        {{/groupselector}}
        {{#userselector}}
            <span class="d-none" data-region="courseid" data-courseid="{{courseid}}" aria-hidden="true"></span>
            <div class="navitem flex-column">
                {{#content}}
                    {{>core/comboboxsearch}}
                {{/content}}
            </div>
            <div class="navitem-divider"></div>
        {{/userselector}}
        <div class="d-flex ms-sm-auto">
            {{#viewasselector}}
                <div class="navitem-divider"></div>
                <div class="navitem">
                    {{>gradereport_user/view_mode_selector}}
                </div>
                <div class="navitem-divider"></div>
            {{/viewasselector}}
        </div>
    </div>
</div>
