{{!
    This file is part of Moodle - http://moodle.org/

    Moodle is free software: you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
    the Free Software Foundation, either version 3 of the License, or
    (at your option) any later version.

    Moodle is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    GNU General Public License for more details.

    You should have received a copy of the GNU General Public License
    along with Moodle.  If not, see <http://www.gnu.org/licenses/>.
}}
{{!
    @template core_admin/setting_savebutton

    Admin save button settings template.

    Example context (json):
    {
    }
}}
{{!
    Settings.
}}
<div class="row">
    <div class="offset-sm-3 col-sm-3">
        <button type="submit" class="btn btn-primary">{{#str}}savechanges, admin{{/str}}</button>
    </div>
</div>
